@@ -1,6 +1,6 @@
 package Bio::DB::Bam::AlignWrapper;
 
-# $Id: AlignWrapper.pm 24231 2010-11-23 22:20:26Z lstein $
+# $Id$
 
 =head1 NAME
 
@@ -123,7 +123,7 @@ sub split_splices {
 							  -start  => $s,
 							  -end    => $e,
 							  -seq_id => $self->seq_id,
-							  -strand => +1,
+							  -strand => $self->strand,
 							  -seq    => [$self,$start+$skip,$end-$start], # deferred rendering
 							  -type   => $self->type);
 
